"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
const jq = require("node-jq");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'data.jq');
class JQ extends command_1.SfdxCommand {
    async run() {
        const inputfilename = this.flags.inputfilename;
        const outputfilename = this.flags.outputfilename;
        const filter = this.flags.filter;
        const options = {};
        const output = await jq.run(filter, inputfilename, options);
        console.log(output);
        fs.writeFileSync(outputfilename, JSON.stringify(output, null, 2));
        return {};
    }
}
JQ.description = messages.getMessage('commandDescription');
JQ.examples = [
    `
    ** ${messages.getMessage('commandDescription')} **

    sfdx mohanc:data:jq -i /tmp/Accounts.json -f '.records[0]' -o /tmp/Accounts.out.json

    bash script to process all the files in a folder:
    ------------
    for file in /tmp/*
    do
        echo Processing "$file" ...
        sfdx mohanc:data:jq  -i $file -o $file.out.json -f '.records[0]'
    done
    -----------
    `
];
JQ.flagsConfig = {
    inputfilename: command_1.flags.string({ char: 'i', description: messages.getMessage('inputfileFlagDescription') }),
    outputfilename: command_1.flags.string({ char: 'o', description: messages.getMessage('outputfileFlagDescription') }),
    filter: command_1.flags.string({ char: 'f', description: messages.getMessage('filterDescription') })
};
exports.default = JQ;
//# sourceMappingURL=jq.js.map