"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
// import * as jsforce from 'jsforce';
const sfdcLogin_1 = require("../../../helper/sfdcLogin");
// import { string } from '@oclif/parser/lib/flags';
// import { readFile } from 'jsonfile';
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'data.loader');
class Loader extends command_1.SfdxCommand {
    async run() {
        // process input flags
        const name = this.flags.sobjectname || 'Account';
        const dataFile = this.flags.datafile || 'inputData.json';
        const loginfile = this.flags.loginfile || 'NONE';
        const orgname = this.flags.orgname || 'NONE';
        // loading mode : batch or nobatch
        const mode = this.flags.mode || 'nobatch';
        function rewriteInputFileWithNewHeader(df, newHeader) {
        }
        function getMappedHeader(inputHeaderLine, map) {
            const inputHeaderFields = inputHeaderLine.split(',');
            const mappedHeader = [];
            for (const inputHeaderField of inputHeaderFields) {
                mappedHeader.push(map.get(inputHeaderField));
            }
            return mappedHeader;
        }
        function readFieldMap(fieldMapFile) {
            const mapContent = fs.readFileSync(fieldMapFile, 'utf8');
            const mapLines = mapContent.split('\n');
            // .pop(); // also remove the last element
            const resultMap = new Map();
            for (const line of mapLines) {
                const [l, r] = line.split('=');
                if (r !== undefined) {
                    resultMap.set(r, l);
                }
            }
            return resultMap;
        }
        let dataFileType = 'json';
        if (dataFile.endsWith('csv')) {
            dataFileType = 'csv';
        }
        else if (dataFile.endsWith('json')) {
            dataFileType = 'json';
        }
        if (loginfile !== 'NONE') { // sandbox/prod access
            const forceLogin = new sfdcLogin_1.SfdcLogin(orgname);
            const sfc = await forceLogin.sfdcLogin(loginfile);
            console.log(`*** userInfo: ${JSON.stringify(sfc.userInfo)}`);
            processLoading(sfc);
        }
        else {
            // Scratch org access
            const sfc = this.org.getConnection();
            const fieldMap = readFieldMap('fieldMap.sdl');
            console.log(fieldMap);
            console.log(getMappedHeader('onee,twoo,threee', fieldMap).join(','));
            processLoading(sfc);
        }
        function processLoading(sfConnection) {
            // we got csv data file TODO: fix the errors
            if (dataFileType === 'csv') { // auto to batch mode
                // ref: https://community.risingstack.com/the-definitive-guide-to-object-streams-in-node-js/    
                console.log(`** MODE: ${dataFileType} insert into ${name} **`);
                const csvFileIn = fs.createReadStream(dataFile);
                // const options: jsforce.BulkOptions = null;
                sfConnection.bulk.load(name, 'insert', csvFileIn, (errors, results) => {
                    if (errors) {
                        return console.error(errors);
                    }
                    for (let i = 0; i < results.length; i++) {
                        if (results[i].success) {
                            console.log(`# ${i + 1} loaded successfully, id = ${results[i].id}`);
                        }
                        else {
                            console.log(`# + ${i + 1} error occurred, message : ${results[i].errors.join(', ')} `);
                        }
                    }
                });
            } // csv
            // we got json data file
            if (dataFileType === 'json') {
                fs.readFile(dataFile, (err, data) => {
                    console.log(`dataFile: ${data}`);
                    const records = JSON.parse(data.toString()).records;
                    if (mode === 'batch') {
                        console.log(`** MODE: ${mode} **`);
                        const job = sfConnection.bulk.createJob(name, 'insert');
                        const batch = job.createBatch();
                        batch.execute(records);
                        batch.on('error', batchInfo => {
                            console.log(`ERROR: batchInfo:${JSON.stringify(batchInfo, null, 2)}`);
                        });
                        batch.on('queue', batchInfo => {
                            console.log(`batchInfo: ${JSON.stringify(batchInfo, null, 2)}`);
                            batch.poll(1000, 20000); // start polling
                        });
                        batch.on('response', results => {
                            for (let i = 0; i < results.length; i++) {
                                if (results[i].success) {
                                    console.log(`# ${i + 1} loaded successfully, id = ${results[i].id}`);
                                    // console.log("#" + (i+1) + " loaded successfully, id = " + rets[i].id);
                                }
                                else {
                                    console.log(`# ${i + 1} error occurred, message = ${results[i].errors.join(', ')}`);
                                    // console.log("#" + (i+1) + " error occurred, message = " + rets[i].errors.join(', '));
                                }
                            }
                        });
                    }
                    else { // nobatch mode
                        console.log(`** MODE: ${mode} **`);
                        const insertResult = sfConnection.insert(name, records);
                        insertResult.then(res => {
                            console.log(res);
                        })
                            .catch(error => {
                            console.log(error);
                        });
                    }
                });
            } // json
        }
        // this.ux.log(`dataFile: ${JSON.stringify(dataFileContent, null, 2)}`);
        return {};
    }
}
Loader.description = messages.getMessage('commandDescription');
Loader.examples = [
    `
    ** ${messages.getMessage('commandDescription')} **

    sfdx mohanc:data:loader -u  mohan.chinnappan.n-hhet@force.com -d harvest_field.csv -n Harvest_Field__c -m batch

    PriceBook2:
     load: sfdx mohanc:data:loader -u TestOrg2 -d Pricebook2s.json  -n 'PriceBook2'
     query: sfdx force:data:soql:query -q 'Select Id, Name FROM PriceBook2' -u TestOrg2

    Product:
     load:  sfdx mohanc:data:loader -u TestOrg2 -d Product2s.json  -n 'Product2' -m batch
     query: sfdx force:data:soql:query -q 'Select id,Name,Description,ProductCode,isDeleted FROM Product2' -u TestOrg1

  `
];
Loader.args = [{ name: 'file' }];
Loader.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    datafile: command_1.flags.string({ char: 'd', description: messages.getMessage('datafileFlagDescription') }),
    sobjectname: command_1.flags.string({ char: 'n', description: messages.getMessage('sobjectnameFlagDescription') }),
    mode: command_1.flags.string({ char: 'm', description: messages.getMessage('modeFlagDescription') }),
    loginfile: command_1.flags.string({ char: 'l', description: messages.getMessage('loginfileDescription') }),
    orgname: command_1.flags.string({ char: 'o', description: messages.getMessage('orgnameDescription') })
};
// Comment this out if your command does not require an org username
Loader.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Loader.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Loader.requiresProject = false;
exports.default = Loader;
//# sourceMappingURL=loader.js.map