"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'data.transform.contact');
class Contact extends command_1.SfdxCommand {
    async run() {
        const inputfilename = this.flags.inputfilename;
        const outputfilename = this.flags.outputfilename;
        const simple = this.flags.simple;
        const inputData = JSON.parse(fs.readFileSync(inputfilename, 'utf8'));
        // console.log(inputData.records.length);
        // Return an object to be displayed with --json
        // get the connection
        const conn = this.org.getConnection();
        // declare a map to use for all text replacements
        const contactMap = new Map();
        const entity = 'Contact';
        const query = 'SELECT Id, Name FROM Contact ORDER BY Name';
        const queryResult = await conn.query(query);
        for (const rec of queryResult.records) {
            contactMap[`${entity}.${rec.Name}`] = rec.Id;
        }
        console.log(contactMap);
        for (const rec of inputData.records) {
            if (rec.Contact !== undefined) {
                const name = rec.Contact.Name;
                const attributes = rec.Contact.attributes;
                // console.log(sObjectType, developerName, attributes);
                const key = `${entity}.${name}`;
                const mapped = contactMap[key];
                console.log(`mapped: ${mapped} for key: ${key}`);
                if (simple === 'y') {
                    rec.ContactId = mapped;
                    console.log(`Deleting ${entity}  Object...`);
                    delete rec.Contact;
                }
                else {
                    // console.log(`Match found: ${mapped}`);
                    // replace recordTypeId at the end of the url to the mapped recordTypeId
                    attributes.url = attributes.url.replace(/(.*\/)(.*)$/, '$1' + mapped);
                    // console.log(`new attributes: ${JSON.stringify(attributes, null, 2)}`);
                }
            }
            else {
                console.log('NO MAP found');
            }
        }
        // output the transformed to the output file
        console.log(`Writing output file: ${outputfilename}`);
        fs.writeFileSync(outputfilename, JSON.stringify(inputData, null, 2));
        return {};
    }
}
Contact.description = messages.getMessage('commandDescription');
Contact.examples = [
    `
     ** ${messages.getMessage('commandDescription')} **

     sfdx mohanc:data:transform:contact -i /tmp/input.json -o /tmp/input.out.json -s y|n

    bash script to process all the files in a folder:
    ------------
    for file in /tmp/*
    do
        echo Processing "$file" ...
        sfdx mohanc:data:transform:contact -i $file -o $file.out.json -s y|n
    done
    -----------

    `
];
Contact.flagsConfig = {
    inputfilename: command_1.flags.string({ char: 'i', description: messages.getMessage('inputfileFlagDescription') }),
    outputfilename: command_1.flags.string({ char: 'o', description: messages.getMessage('outputfileFlagDescription') }),
    simple: command_1.flags.string({ char: 's', description: messages.getMessage('simpleDescription') })
};
// Comment this out if your command does not require an org username
Contact.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Contact.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Contact.requiresProject = false;
exports.default = Contact;
//# sourceMappingURL=contact.js.map