"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const through2 = require("through2");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages("sfdx-mohanc-plugins", "data.jq");
class CSV extends command_1.SfdxCommand {
    async run() {
        const parseCSV = () => {
            let templateKeys = [];
            let parseHeadline = true;
            return through2.obj((data, enc, cb) => {
                console.log(data.toString());
                if (parseHeadline) {
                    templateKeys = data.toString().split(',');
                    parseHeadline = false;
                    console.log(templateKeys);
                    return cb(null, null);
                }
                const entries = data.toString().split(',');
                const obj = {};
                templateKeys.forEach((el, index) => {
                    obj[el] = entries[index];
                });
                return cb(null, obj);
            });
        };
        const toUpperCase = through2((data, enc, cb) => {
            cb(null, new Buffer(data.toString().toUpperCase()));
        });
        const dashBetweenWords = through2((data, enc, cb) => {
            cb(null, new Buffer(data.toString().split('').join('-')));
        });
        process.stdin
            .pipe(toUpperCase)
            // .pipe(dashBetweenWords)
            .pipe(parseCSV())
            .pipe(process.stdout);
        /*
        const generator = csvgenerate({ length: 20 });
        const parser = csvparse({ delimiter: ',' });
        const transformer = transform(
          (record, callback) => {
            console.log(`record: ${record}`);
            setTimeout(() => {
              callback(null, record.join(' ') + '');
            }, 500);
          },
          { parallel: 5 }
        );
    
        generator
          .pipe(parser)
          .pipe(transformer)
          .pipe(process.stdout)
          ;
        */
        return {};
    }
}
CSV.description = messages.getMessage("commandDescription");
CSV.examples = [
    `
    ** ${messages.getMessage("commandDescription")} **

    sfdx mohanc:data:jq -i /tmp/Accounts.json -f '.records[0]' -o /tmp/Accounts.out.json

    bash script to process all the files in a folder:
    ------------
    for file in /tmp/*
    do
        echo Processing "$file" ...
        sfdx mohanc:data:jq  -i $file -o $file.out.json -f '.records[0]'
    done
    -----------
    `
];
CSV.flagsConfig = {
    inputfilename: command_1.flags.string({
        char: 'i',
        description: messages.getMessage('inputfileFlagDescription')
    }),
    outputfilename: command_1.flags.string({
        char: 'o',
        description: messages.getMessage('outputfileFlagDescription')
    }),
    filter: command_1.flags.string({
        char: 'f',
        description: messages.getMessage('filterDescription')
    })
};
exports.default = CSV;
//# sourceMappingURL=csv.js.map