"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'data.transform.profile');
class Profile extends command_1.SfdxCommand {
    async run() {
        const inputfilename = this.flags.inputfilename;
        const outputfilename = this.flags.outputfilename;
        const simple = this.flags.simple;
        const inputData = JSON.parse(fs.readFileSync(inputfilename, 'utf8'));
        // console.log(inputData.records.length);
        // Return an object to be displayed with --json
        // get the connection
        const conn = this.org.getConnection();
        // declare a map to use for all text replacements
        const profileMap = new Map();
        const profileQuery = `
    Select Id, Name
            FROM  Profile
            ORDER BY Name
    `;
        const profileResult = await conn.query(profileQuery);
        for (const rec of profileResult.records) {
            profileMap[`Profile.${rec.Name}`] = rec.Id;
        }
        console.log(profileMap);
        for (const rec of inputData.records) {
            if (rec.ProfileName !== undefined) {
                const mapped = profileMap[`Profile.${rec.ProfileName.Name}`];
                if (mapped !== undefined) {
                    if (simple === 'y') {
                        rec.SetupOwnerId = mapped;
                        console.log('Deleting ProfileName Object...');
                        delete rec.ProfileName;
                    }
                    else {
                        console.log(`Match found: ${mapped}`);
                        rec.ProfileName.attributes.url = rec.ProfileName.attributes.url.replace(/(.*\/)(.*)$/, '$1' + mapped);
                    }
                }
                else {
                    console.log('NO MAP found');
                }
            }
            else {
                console.log('ProfileName: NOT FOUND');
            }
        }
        // output the transformed to the output file
        console.log(`Writing output file: ${outputfilename}`);
        fs.writeFileSync(outputfilename, JSON.stringify(inputData, null, 2));
        return {};
    }
}
Profile.description = messages.getMessage('commandDescription');
Profile.examples = [
    `
    ** ${messages.getMessage('commandDescription')} **

    sfdx mohanc:data:transform:profile -i /tmp/input.json -o /tmp/output.json -s n

    bash script to process all the files in a folder:
    ------------
    for file in /tmp/*
    do
        echo Processing "$file" ...
        sfdx mohanc:data:transform:profile -i $file -o $file.out.json -s y|n
    done
    -----------
    `
];
Profile.flagsConfig = {
    inputfilename: command_1.flags.string({ char: 'i', description: messages.getMessage('inputfileFlagDescription') }),
    outputfilename: command_1.flags.string({ char: 'o', description: messages.getMessage('outputfileFlagDescription') }),
    simple: command_1.flags.string({ char: 's', description: messages.getMessage('simpleDescription') })
};
// Comment this out if your command does not require an org username
Profile.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Profile.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Profile.requiresProject = false;
exports.default = Profile;
//# sourceMappingURL=profile.js.map