"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'data.transform.rt');
class RT extends command_1.SfdxCommand {
    async run() {
        const inputfilename = this.flags.inputfilename;
        const outputfilename = this.flags.outputfilename;
        const simple = this.flags.simple;
        const sobjectname = this.flags.sobjectname;
        const inputData = JSON.parse(fs.readFileSync(inputfilename, 'utf8'));
        // console.log(inputData.records.length);
        // Return an object to be displayed with --json
        // get the connection
        const conn = this.org.getConnection();
        // declare a map to use for all text replacements
        const rtMap = new Map();
        const recordTypeQuery = `
    Select Id,
            SobjectType,
            DeveloperName
            FROM  RecordType
            WHERE
                IsActive=true
            ORDER BY
              SObjectType, DeveloperName
    `;
        const recordTypeResult = await conn.query(recordTypeQuery);
        for (const rec of recordTypeResult.records) {
            rtMap[`${rec.SobjectType}.${rec.DeveloperName}`] = rec.Id;
        }
        console.log(rtMap);
        for (const rec of inputData.records) {
            if (rec.RecordType !== undefined) {
                const sObjectType = sobjectname || rec.attributes.type;
                console.log(`sObjectType: ${sObjectType}`);
                const developerName = rec.RecordType.DeveloperName;
                const attributes = rec.RecordType.attributes;
                // console.log(sObjectType, developerName, attributes);
                const mapped = rtMap[`${sObjectType}.${developerName}`];
                console.log(`mapped: ${mapped}`);
                if (mapped !== undefined) {
                    if (simple === 'y') {
                        rec.RecordTypeId = mapped;
                        console.log('Deleting RecordType Object...');
                        delete rec.RecordType;
                    }
                    else {
                        // console.log(`Match found: ${mapped}`);
                        // replace recordTypeId at the end of the url to the mapped recordTypeId
                        attributes.url = attributes.url.replace(/(.*\/)(.*)$/, '$1' + mapped);
                        // console.log(`new attributes: ${JSON.stringify(attributes, null, 2)}`);
                    }
                }
                else {
                    console.log('NO MAP found');
                }
            }
            else {
                console.log('RecordType: NOT FOUND');
            }
        }
        // output the transformed to the output file
        console.log(`Writing output file: ${outputfilename}`);
        fs.writeFileSync(outputfilename, JSON.stringify(inputData, null, 2));
        return {};
    }
}
RT.description = messages.getMessage('commandDescription');
RT.examples = [
    `
    ** ${messages.getMessage('commandDescription')} **

    sfdx mohanc:data:transform:rt -i /tmp/Accounts.json -o /tmp/Accounts.out.json -s n -e <sobjectName>

    bash script to process all the files in a folder:
    ------------
    for file in /tmp/*
    do
        echo Processing "$file" ...
        sfdx mohanc:data:transform:rt -i $file -o $file.out.json -s y|n -e Account
    done
    -----------
    `
];
RT.flagsConfig = {
    inputfilename: command_1.flags.string({ char: 'i', description: messages.getMessage('inputfileFlagDescription') }),
    outputfilename: command_1.flags.string({ char: 'o', description: messages.getMessage('outputfileFlagDescription') }),
    simple: command_1.flags.string({ char: 's', description: messages.getMessage('simpleDescription') }),
    sobjectname: command_1.flags.string({ char: 'e', description: messages.getMessage('sobjectFlagDescription') })
};
// Comment this out if your command does not require an org username
RT.requiresUsername = true;
// Comment this out if your command does not support a hub org username
RT.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
RT.requiresProject = false;
exports.default = RT;
//# sourceMappingURL=rt.js.map