"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'data.transform.simplify');
class Simplify extends command_1.SfdxCommand {
    async run() {
        const inputfilename = this.flags.inputfilename;
        const outputfilename = this.flags.outputfilename;
        const sobjectname = this.flags.sobjectname;
        const aliasname = this.flags.aliasname || sobjectname;
        // get the connection
        const conn = this.org.getConnection();
        const inputData = JSON.parse(fs.readFileSync(inputfilename, 'utf8'));
        // TODO: add validation
        // get the object type we are dealing with by smelling the first record
        const sobjectType = inputData.records[0][sobjectname].attributes.type;
        // declare a map to use for all text replacements
        const objectMap = new Map();
        const query = `SELECT Id, Name FROM ${sobjectType} ORDER BY Name`;
        console.log(`query: ${query}`);
        const queryResult = await conn.query(query);
        for (const rec of queryResult.records) {
            objectMap[`${sobjectType}.${rec.Name}`] = rec.Id;
        }
        console.log(objectMap);
        for (const rec of inputData.records) {
            if (rec[sobjectname] !== undefined) {
                const attributes = rec[sobjectname].attributes;
                // $ cat /tmp/task.in.json  | jq '.records[0].WhatId.attributes.url'
                // "/services/data/v44.0/sobjects/Account/0011D00000R0UiNQAV"
                const name = rec[sobjectname].Name;
                const key = `${attributes.type}.${name}`;
                const mappedId = objectMap[key];
                console.log(`mapped: ${mappedId} for key: ${key}`);
                console.log(`Deleting ${sobjectname} Object...`);
                delete rec[sobjectname];
                console.log(`Adding "${sobjectname}": "${mappedId}" key:value...`);
                // rec[sobjectname] = mappedId;
                rec[aliasname] = mappedId;
            }
        }
        // output the transformed to the output file
        console.log(`Writing output file: ${outputfilename}`);
        fs.writeFileSync(outputfilename, JSON.stringify(inputData, null, 2));
        return {};
    }
}
Simplify.description = messages.getMessage('commandDescription');
Simplify.examples = [
    `
     ** ${messages.getMessage('commandDescription')} **

     sfdx mohanc:data:transform:simplify -i /tmp/input.json -o /tmp/input.out.json -e sobjectName -a aliasName

    bash script to process all the files in a folder:
    ------------
    for file in /tmp/*
    do
        echo Processing "$file" ...
        sfdx mohanc:data:transform:simplify -i $file -o $file.out.json -e sobjectName -a aliasName
    done
    -----------

    `
];
Simplify.flagsConfig = {
    inputfilename: command_1.flags.string({ char: 'i', description: messages.getMessage('inputfileFlagDescription') }),
    outputfilename: command_1.flags.string({ char: 'o', description: messages.getMessage('outputfileFlagDescription') }),
    sobjectname: command_1.flags.string({ char: 'e', description: messages.getMessage('sobjectFlagDescription') }),
    aliasname: command_1.flags.string({ char: 'a', description: messages.getMessage('aliasnameFlagDescription') })
};
// Comment this out if your command does not require an org username
Simplify.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Simplify.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Simplify.requiresProject = false;
exports.default = Simplify;
//# sourceMappingURL=simplify.js.map