"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'data.transform.un');
class UN extends command_1.SfdxCommand {
    getUniqueStr(len) {
        let out = '';
        const stringSpan = 'ABCDEFGHIJKLMNOPQRSTUVWZYZ0123456790';
        for (let i = 0; i < len; i++) {
            const rand = Math.floor(Math.random() * stringSpan.length);
            out += stringSpan.charAt(rand);
        }
        return out;
    }
    async run() {
        const inputfilename = this.flags.inputfilename;
        const outputfilename = this.flags.outputfilename;
        const inputData = JSON.parse(fs.readFileSync(inputfilename, 'utf8'));
        const joinStr = '_';
        // console.log(inputData.records.length);
        for (const rec of inputData.records) {
            if (rec.Username !== undefined && rec.Email !== undefined) {
                // add uniqueStr to the email to form unique username
                const uniqueStr = this.getUniqueStr(6);
                rec.Username = `${uniqueStr}${joinStr}${rec.Email}`;
            }
        }
        // output the transformed to the output file
        console.log(`Writing output file: ${outputfilename}`);
        fs.writeFileSync(outputfilename, JSON.stringify(inputData, null, 2));
        return {};
    }
}
UN.description = messages.getMessage('commandDescription');
UN.examples = [
    `
     ** ${messages.getMessage('commandDescription')} **

    sfdx mohanc:data:transform:un -i /tmp/input.json -o /tmp/input.out.json

    bash script to process all the files in a folder:
    ------------
    for file in /tmp/*
    do
        echo Processing "$file" ...
        sfdx mohanc:data:transform:un -i $file -o $file.out.json
    done
    -----------

    `
];
UN.flagsConfig = {
    inputfilename: command_1.flags.string({ char: 'i', description: messages.getMessage('inputfileFlagDescription') }),
    outputfilename: command_1.flags.string({ char: 'o', description: messages.getMessage('outputfileFlagDescription') }),
};
exports.default = UN;
//# sourceMappingURL=un.js.map