"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'data.transform.ur');
class UR extends command_1.SfdxCommand {
    async run() {
        const inputfilename = this.flags.inputfilename;
        const outputfilename = this.flags.outputfilename;
        const simple = this.flags.simple;
        const inputData = JSON.parse(fs.readFileSync(inputfilename, 'utf8'));
        // console.log(inputData.records.length);
        // Return an object to be displayed with --json
        // get the connection
        const conn = this.org.getConnection();
        // declare a map to use for all text replacements
        const urMap = new Map();
        const userRoleQuery = 'SELECT Id, DeveloperName FROM UserRole ORDER BY DeveloperName';
        const userRoleResult = await conn.query(userRoleQuery);
        for (const rec of userRoleResult.records) {
            urMap[`User.${rec.DeveloperName}`] = rec.Id;
        }
        console.log(urMap);
        for (const rec of inputData.records) {
            if (rec.UserRole !== undefined) {
                const sObjectType = rec.attributes.type;
                const developerName = rec.UserRole.DeveloperName;
                const attributes = rec.UserRole.attributes;
                // console.log(sObjectType, developerName, attributes);
                const key = `${sObjectType}.${developerName}`;
                const mapped = urMap[key];
                console.log(`mapped: ${mapped} for key: ${key}`);
                if (mapped !== undefined) {
                    if (simple === 'y') {
                        rec.UserRoleId = mapped;
                        console.log('Deleting UserRole Object...');
                        delete rec.UserRole;
                    }
                    else {
                        attributes.url = attributes.url.replace(/(.*\/)(.*)$/, '$1' + mapped);
                        // console.log(`new attributes: ${JSON.stringify(attributes, null, 2)}`);
                    }
                }
                else {
                    console.log('NO MAP found');
                }
            }
            else {
                console.log('UserRole: NOT FOUND');
            }
        }
        // output the transformed to the output file
        console.log(`Writing output file: ${outputfilename}`);
        fs.writeFileSync(outputfilename, JSON.stringify(inputData, null, 2));
        return {};
    }
}
UR.description = messages.getMessage('commandDescription');
UR.examples = [
    `
    ** ${messages.getMessage('commandDescription')} **

    sfdx mohanc:data:transform:ur -i /tmp/input.json -o /tmp/input.out.json -s y|n

    bash script to process all the files in a folder:
    ------------
    for file in /tmp/*
    do
        echo Processing "$file" ...
        sfdx mohanc:data:transform:ur -i $file -o $file.out.json -s y|n
    done
    -----------

    `
];
UR.flagsConfig = {
    inputfilename: command_1.flags.string({ char: 'i', description: messages.getMessage('inputfileFlagDescription') }),
    outputfilename: command_1.flags.string({ char: 'o', description: messages.getMessage('outputfileFlagDescription') }),
    simple: command_1.flags.string({ char: 's', description: messages.getMessage('simpleDescription') })
};
// Comment this out if your command does not require an org username
UR.requiresUsername = true;
// Comment this out if your command does not support a hub org username
UR.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
UR.requiresProject = false;
exports.default = UR;
//# sourceMappingURL=ur.js.map