"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
const readline = require("readline");
const csvparse_1 = require("../../../helper/csvparse");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'data.tx');
class TX extends command_1.SfdxCommand {
    async run() {
        const csvparser = new csvparse_1.CSVParse();
        const inputfilename = this.flags.inputfilename;
        const txfilename = this.flags.txfilename;
        const dlim = this.flags.delim || ',';
        const txData = JSON.parse(fs.readFileSync(txfilename, 'utf8'));
        const lineReader = readline.createInterface({
            input: fs.createReadStream(inputfilename)
        });
        let index = 0;
        let header;
        // convert a given record to an object
        function rec2obj(hdr, flds) {
            let i = 0;
            const obj = {};
            for (const hdrFld of hdr) {
                obj[hdrFld] = flds[i];
                i++;
            }
            return obj;
        }
        function fillTemplate(ts, tvars) {
            return new Function("return `" + ts + "`;").call(tvars);
        }
        // get rec for the given object
        function obj2rec(rec, delimiter) {
            const fields = [];
            const keys = Object.keys(rec);
            for (const key of keys) {
                fields.push(rec[key]);
            }
            return fields.join(delimiter);
        }
        // get the header record
        function obj2recHeader(rec, delimiter) {
            return Object.keys(rec).join(delimiter);
        }
        function processRec(rec, txd) {
            // console.log(`rec: ${ JSON.stringify(rec, null,2)}`);
            for (const tx of txd.tx) {
                // console.log(tx);
                const templateString = tx.v;
                // console.log(templateString);
                const fieldName = tx.n;
                const result = fillTemplate(templateString, rec);
                const fieldType = tx.t;
                switch (fieldType) {
                    case 'float':
                        rec[fieldName] = Number.parseFloat(result);
                        break;
                    case 'int':
                        rec[fieldName] = Number.parseInt(result);
                        break;
                    default:
                        rec[fieldName] = result;
                        break;
                }
            }
            return rec;
        }
        lineReader.on('line', line => {
            index++;
            if (index === 1) {
                // header = line.split(dlim);
                header = csvparser.parse(line, dlim)[0];
                // console.log(headerData[0]);
            }
            if (index > 1) {
                // const fields = line.split(dlim);
                const fields = csvparser.parse(line, dlim)[0];
                const rec = rec2obj(header, fields);
                const outRec = processRec(rec, txData);
                const headerRec = obj2recHeader(rec, dlim);
                if (index === 2) {
                    console.log(headerRec);
                }
                console.log(obj2rec(outRec, dlim));
            }
        });
        return {};
    }
}
TX.description = messages.getMessage('commandDescription');
TX.examples = [
    `
    ** ${messages.getMessage('commandDescription')} **

    sfdx mohanc:data:tx -i /tmp/input.psv  -t /tmp/tx.json  -d  '|'

    `
];
TX.flagsConfig = {
    inputfilename: command_1.flags.string({ char: 'i', description: messages.getMessage('inputfileFlagDescription') }),
    txfilename: command_1.flags.string({ char: 't', description: messages.getMessage('txfileFlagDescription') }),
    delim: command_1.flags.string({ char: 'd', description: messages.getMessage('delimiterDescription') })
};
exports.default = TX;
//# sourceMappingURL=tx.js.map