"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
const readline = require("readline");
const csvparse_1 = require("../../../helper/csvparse");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'data.vlookup');
class Vlookup extends command_1.SfdxCommand {
    async run() {
        const mapfilename = this.flags.mapfilename;
        const inputfilename = this.flags.inputfilename;
        const dlim = this.flags.delim;
        // console.log(this.flags.mapfrom);
        const mapFrom = this.flags.mapfrom || 0;
        const mapTo = this.flags.mapto || 1;
        const data = fs.readFileSync(mapfilename, 'utf8');
        const csvparser = new csvparse_1.CSVParse();
        const arrData = csvparser.parse(data, dlim);
        const header = arrData[0];
        let index = 0;
        const max = arrData.length;
        const vMap = new Map();
        for (const rec of arrData) {
            index++;
            if (index > 1 && index !== max) {
                // console.log (rec);
                vMap[rec[mapFrom]] = rec[mapTo];
            }
        }
        // console.log(vMap);
        const lineReader = readline.createInterface({
            input: fs.createReadStream(inputfilename)
        });
        index = 0;
        lineReader.on('line', line => {
            index++;
            if (index > 1) {
                // const recs = line.split(dlim);
                const recs = csvparser.parse(line, dlim)[0];
                console.log(`${line}${dlim}${vMap[recs[0]]}`);
            }
            else {
                console.log(`${line}${dlim}mapped`);
            }
        });
        return {};
    }
}
Vlookup.description = messages.getMessage('commandDescription');
Vlookup.examples = [
    `
    ** ${messages.getMessage('commandDescription')} **

    sfdx mohanc:data:vlookup -m /tmp/cats.psv  -i /tmp/items.psv -d '|'
   
    `
];
Vlookup.flagsConfig = {
    mapfilename: command_1.flags.string({ char: 'm', description: messages.getMessage('mapfileFlagDescription') }),
    inputfilename: command_1.flags.string({ char: 'i', description: messages.getMessage('inputfileFlagDescription') }),
    delim: command_1.flags.string({ char: 'd', description: messages.getMessage('delimiterDescription') }),
    mapfrom: command_1.flags.string({ char: 'f', description: messages.getMessage('mapfromDescription') }),
    mapto: command_1.flags.string({ char: 't', description: messages.getMessage('maptoDescription') })
};
exports.default = Vlookup;
//# sourceMappingURL=vlookup.js.map