"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const RestUtils_1 = require("../../../helper/RestUtils");
const sfdcLogin_1 = require("../../../helper/sfdcLogin");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'ea.query');
class EAQuery extends command_1.SfdxCommand {
    async run() {
        const loginfilename = this.flags.loginfilename || 'NONE';
        const orgname = this.flags.orgname || 'org40';
        const resource = this.flags.resource || 'dashboards';
        const restUtils = new RestUtils_1.RESTUtil();
        if (loginfilename !== 'NONE') { // sandbox/prod access
            const forceLogin = new sfdcLogin_1.SfdcLogin(orgname);
            const sfdcConn = await forceLogin.sfdcLogin(loginfilename);
            // console.log(`*** userInfo: ${JSON.stringify(sfdcConn.userInfo, null, 2)}`);
            const instanceUrl = sfdcConn.conn.instanceUrl;
            const accessToken = sfdcConn.conn.accessToken;
            const apiVersion = sfdcConn.conn.version;
            const eaUrl = `${instanceUrl}/services/data/v${apiVersion}/wave/${resource}`;
            // console.info(`eaUrl: ${eaUrl}`);
            restUtils.sfdcGet(eaUrl, accessToken).then((eaResult) => {
                console.log(JSON.stringify(eaResult, null, 2));
            });
        }
        else { // Scratch org
            const conn = this.org.getConnection();
            const instanceUrl = conn.instanceUrl;
            const accessToken = conn.accessToken;
            const apiVersion = conn.version;
            const eaUrl = `${instanceUrl}/services/data/v${apiVersion}/wave/${resource}`;
            // console.info(`eaUrl: ${eaUrl}`);
            restUtils.sfdcGet(eaUrl, accessToken).then((eaResult) => {
                console.log(JSON.stringify(eaResult, null, 2));
            });
        }
        // Return an object to be displayed with --json
        return {};
    }
}
EAQuery.description = messages.getMessage('commandDescription');
EAQuery.examples = [
    ` 
      sfdx force:auth:web:login -r https://login.salesforce.com
      $ sfdx force:org:list
      === Orgs
     ALIAS     USERNAME                            ORG ID              CONNECTED STATUS
               mohan.chinnappan.n_ea@gmail.com     00D1N000001Tjk2UAC  Connected

      sfdx mohanc:ea:query  -u  mohan.chinnappan.n_ea@gmail.com    -r dashboards > dashboards.json

      resources:
      1. dashboards
      2. dataConnectorTypes
      3. dataConnectors
      4. dataflowjobs
      5. folders
      6. lenses
      7. query
      8. recipes
      9. templates
      10. trendedreports

    `
];
EAQuery.flagsConfig = {
    loginfilename: command_1.flags.string({ char: 'l', description: messages.getMessage('loginfileNameDescription') }),
    orgname: command_1.flags.string({ char: 'o', description: messages.getMessage('orgnameDescription') }),
    resource: command_1.flags.string({ char: 'r', description: messages.getMessage('resourceDescription') })
};
// Comment this out if your command does not require an org username
EAQuery.requiresUsername = true;
// Comment this out if your command does not support a hub org username
EAQuery.supportsDevhubUsername = true;
exports.default = EAQuery;
//# sourceMappingURL=query.js.map