"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const sfdcLogin_1 = require("../../../helper/sfdcLogin");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'md.describeGlobal');
class DescribeGlobal extends command_1.SfdxCommand {
    async run() {
        const loginfilename = this.flags.loginfilename || 'NONE';
        const orgname = this.flags.orgname || 'org40';
        const outputformat = this.flags.outputformat || 'csv';
        if (loginfilename !== 'NONE') { // sandbox/prod access
            const forceLogin = new sfdcLogin_1.SfdcLogin(orgname);
            const sfdcConn = await forceLogin.sfdcLogin(loginfilename);
            // console.log(`*** userInfo: ${JSON.stringify(sfdcConn.userInfo, null, 2)}`);
            const result = await sfdcConn.conn.describeGlobal();
            const sobjList = [];
            for (const sobj of result.sobjects) {
                sobjList.push(sobj.name);
            }
            console.log(sobjList.join(','));
        }
        else { // Scratch org
            const conn = this.org.getConnection();
            const sobjList = [];
            const result = await conn.describeGlobal();
            for (const sobj of result.sobjects) {
                sobjList.push(sobj.name);
            }
            console.log(sobjList.join(','));
        }
        // Return an object to be displayed with --json
        return {};
    }
}
DescribeGlobal.description = messages.getMessage('commandDescription');
DescribeGlobal.examples = [
    ` 
      # Scratch org query
      sfdx mohanc:md:describeGlobal   > ObjectList.txt

      // sandbox org: org40
      sfdx mohanc:md:describeGlobal  -l login.json  -o org40 > ObjectList.txt

    `
];
DescribeGlobal.flagsConfig = {
    loginfilename: command_1.flags.string({ char: 'l', description: messages.getMessage('loginfileNameDescription') }),
    outputformat: command_1.flags.string({ char: 'f', description: messages.getMessage('outputFormatDescription') }),
    orgname: command_1.flags.string({ char: 'o', description: messages.getMessage('orgnameDescription') })
};
// Comment this out if your command does not require an org username
DescribeGlobal.requiresUsername = true;
// Comment this out if your command does not support a hub org username
DescribeGlobal.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
DescribeGlobal.requiresProject = false;
exports.default = DescribeGlobal;
//# sourceMappingURL=describeGlobal.js.map