"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'rename');
// Rename metadata : https://jsforce.github.io/document/#rename-metadata
//  Rename fullname of a metadata component in the organization
// http://jsforce.github.io/jsforce/doc/api_metadata.js.html
// https://developer.salesforce.com/docs/atlas.en-us.api_meta.meta/api_meta/meta_renameMetadata.htm
class Rename extends command_1.SfdxCommand {
    async run() {
        // read the flags
        const dataFile = this.flags.renamefile || 'updateData.json';
        // get the connection
        const dataFileContent = fs.readFileSync(dataFile, 'utf8');
        const renameInfo = JSON.parse(dataFileContent)['updates'];
        console.log(`data: ${JSON.stringify(renameInfo, null, 2)}`);
        const bRename = true;
        if (bRename) {
            const conn = this.org.getConnection();
            for (const item of renameInfo) {
                const mdtype = item['mdtype'];
                delete item['mdtype'];
                const metadata = [item];
                console.log(mdtype);
                console.log(metadata);
                conn.metadata.update(mdtype, metadata, (error, results) => {
                    if (error) {
                        return console.error(error);
                    }
                    console.log(`results: ${JSON.stringify(results)}`);
                });
            }
        }
        return { msg: 'from metadata:rename' };
    }
}
Rename.description = messages.getMessage('commandDescription');
Rename.examples = [
    `
         Renames the given metadata type as given in the input file
         sfdx mohanc:md:rename -r update.json

         $ cat update.json | jq
            {
            "updates": [
                {
                "mdtype": "CustomField",
                "fullName": "Account.Hot_Status__c",
                "label": "HOT STAT",
                "type": "Text",
                "length": 12
                }
            ]
            }


      `
];
Rename.requiresUsername = true;
Rename.flagsConfig = {
    renamefile: command_1.flags.string({ char: 'r', description: messages.getMessage('renameFileDescription') }),
};
exports.default = Rename;
//# sourceMappingURL=rename.js.map