"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
const jsonfile = require("jsonfile");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'gen');
/*

    ~/sfdx/cms:
    $ sfdx mohanc:projectFile:gen  --json
    {
    "status": 0,
    "result": {
        "msg": "from projectFile:gen"
    }
    }
*/
class Gen extends command_1.SfdxCommand {
    getProjectFile(id, data) {
        const keys = Object.keys(data);
        const outObj = {};
        outObj['packageDirectories'] = [data['packageDirectories'][id]];
        // other keys
        for (const k of keys) {
            if (keys[k] !== 'packageDirectories') {
                outObj[keys[k]] = data[keys[k]];
            }
        }
        /*
        for (let k = 0; k < keys.length; k++) {
            // console.log(keys[k]);
            if (keys[k] !== 'packageDirectories') {
               outObj[keys[k]] = data[keys[k]];
            }
        }
        */
        return outObj;
    }
    async run() {
        const projectFile = this.flags.projectfile || './sfdx-project.json';
        const targetusername = this.flags.targetusername;
        let uflagData = '-u $targetusername';
        // if (targetusername !== undefined) { uflagData = `-u ${targetusername}`; }
        this.ux.log(`
----------------------------------------------------
projectFile: ${projectFile}
        `);
        jsonfile.readFile(projectFile, (error, data) => {
            this.ux.log(data);
            this.ux.log(`
----------------------------------------------------`);
            const numPks = data['packageDirectories'].length;
            this.ux.log(`Number of project files: ${numPks} `);
            let scriptOut = `
if [ "$#" -ne 2 ]; then
  echo "usage: deploy.sh -u targetusername"
  exit 128
fi
while getopts ":u:" opt; do
case $opt in
    u) targetusername="$OPTARG"
    ;;
    \?) echo "Invalid option -$OPTARG" >&2
    ;;
esac
done
#------ backing up the project file
cp ${projectFile} ${projectFile}.bak.json
#----------`;
            for (let k = 0; k < numPks; k++) {
                const outObj = this.getProjectFile(k, data);
                const outFileName = `${projectFile}.${k}.json`;
                scriptOut += `
cp ${outFileName} ${projectFile}
sfdx force:source:push -f  ${uflagData}
#----------

 `;
                this.ux.log(`Creating project file: ${outFileName}...`);
                fs.writeFileSync(outFileName, JSON.stringify(outObj, null, 2));
            }
            // wireout the script file
            this.ux.log('Writing deploy.sh script file...');
            scriptOut += `
            #------ restoring  the project file
            cp ${projectFile}.bak.json ${projectFile}
            #----------\n`;
            fs.writeFileSync('deploy.sh', scriptOut);
            this.ux.log(`
            ----------------------------------------------------
            ** NEXT STEPS **
            ** View the script: deploy.sh: cat deploy.sh
            ** Run deploy.sh in the bash shell to do the source:push **
            `);
        });
        // const msg = 'test';
        // this.ux.log(`You input --force AND --file: ${msg} `);
        return { msg: 'from projectFile:gen' };
    }
}
Gen.description = messages.getMessage('commandDescription');
Gen.examples = [
    `
** Creates project json files for the given sfdx-project.json
** Creates deploy.sh to run the source:push in sequence

sfdx mohanc:projectFile:gen -p ./sfdx-project.json
----------------------------------------------------
projectFile: ./sfdx-project.json
{ packageDirectories: 
   [ { path: 'force-app/schema', default: true },
     { path: 'force-app/bl' },
     { path: 'force-app/ui' },
     { path: 'force-app/perms' } ],
  namespace: '',
  sfdcLoginUrl: 'https://login.salesforce.com',
  sourceApiVersion: '42.0' }
Number of project files: 4 
Creating project file: ./sfdx-project.json.0.json...
Creating project file: ./sfdx-project.json.1.json...
Creating project file: ./sfdx-project.json.2.json...
Creating project file: ./sfdx-project.json.3.json...
Writing deploy.sh script file...
~/sfdx/test:
$ sfdx mohanc:projectFile:gen -p ./sfdx-project.json
projectFile: ./sfdx-project.json
----------------------------------------------------
{ packageDirectories:
   [ { path: 'force-app/schema', default: true },
     { path: 'force-app/bl' },
     { path: 'force-app/ui' },
     { path: 'force-app/perms' } ],
  namespace: '',
  sfdcLoginUrl: 'https://login.salesforce.com',
  sourceApiVersion: '42.0' }
Number of project files: 4 
Creating project file: ./sfdx-project.json.0.json...
Creating project file: ./sfdx-project.json.1.json...
Creating project file: ./sfdx-project.json.2.json...
Creating project file: ./sfdx-project.json.3.json...
Writing deploy.sh script file...
----------------------------------------------------
** NEXT STEPS **
** View the script: deploy.sh: cat deploy.sh
** Run bash    deploy.sh -u targetusername in the bash shell to do the source:push **
** Run bash -x deploy.sh -u targetusername in the bash shell to do the source:push in verbose mode **


         `
];
Gen.flagsConfig = {
    // flag with a value (-p, --projectFile=VALUE)
    projectfile: command_1.flags.string({ char: 'p', description: messages.getMessage('projectFileFlagDescription') })
    // , targetusername:  flags.string({char:  'u',  description: messages.getMessage('targetUsernameFlagDescription')})
};
exports.default = Gen;
//# sourceMappingURL=gen.js.map