"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'tooling.crud');
class Crud extends command_1.SfdxCommand {
    async run() {
        // read the apex code file
        const toolingObj = this.flags.toolingobj || 'ApexClass';
        const crudMethod = this.flags.method || 'create';
        const objContentFilename = this.flags.objcontentfilename || 'objContent.txt';
        const auraBundleLabel = this.flags.aurabundlelabel;
        console.log(auraBundleLabel);
        const auraType = this.flags.auratype;
        const objContent = fs.readFileSync(objContentFilename, 'utf8');
        console.log(`objContent: ${objContent}`);
        // this.org is guaranteed because requiresUsername=true, as opposed to supportsUsername
        // get the connection
        const conn = this.org.getConnection();
        const orgApiVersion = conn.getApiVersion();
        console.log(`apiVersion: ${orgApiVersion}`);
        console.log(`curdMethod: ${crudMethod}`);
        const lexBundle = 'A Lightning Component Bundle';
        const formats = {
            // COMPONENT — component markup
            COMPONENT: 'XML',
            APPLICATION: 'XML',
            // client-side controller
            CONTROLLER: 'JS',
            // EVENT — event definition
            EVENT: 'JS',
            // HELPER — client-side helper
            HELPER: 'JS',
            // INTERFACE — interface definition
            // RENDERER — client-side renderer
            RENDERER: 'JS',
            // STYLE — style (CSS) resource
            STYLE: 'CSS',
            // PROVIDER — reserved for future use
            //  MODEL — deprecated, do not use
            // TESTSUITE — reserved for future use
            // DOCUMENTATION — documentation markup
            DOCUMENTATION: 'XML',
            // TOKENS — tokens collection
            // DESIGN — design definition
            DESIGN: 'XML',
            // SVG — SVG graphic resource
            SVG: 'SVG'
            // ["XML","JS","CSS","TEMPLATE_CSS","SVG"]
        };
        switch (crudMethod) {
            case 'create':
                switch (toolingObj) {
                    case 'AuraDefinition':
                        const fmt = formats[auraType];
                        // let us create the bundle first
                        conn.tooling.sobject(`${toolingObj}Bundle`).create({ description: lexBundle,
                            developerName: auraBundleLabel.replace(/ /g, ''),
                            masterLabel: auraBundleLabel,
                            apiVersion: orgApiVersion }, (err, res) => {
                            if (err) {
                                return console.error(err);
                            }
                            console.log(`Tooling Crud results ${toolingObj}Bundle: ${JSON.stringify(res, null, 3)}`);
                            // get the id of the bundle created
                            const bundleId = res['id'];
                            console.log(`bundleId: ${bundleId}`);
                            conn.tooling.sobject(toolingObj).create({ defType: auraType, source: objContent,
                                format: fmt,
                                AuraDefinitionBundleId: bundleId }, (err2, res2) => {
                                if (err2) {
                                    return console.error(err2);
                                }
                                console.log(`Tooling Crud results: ${JSON.stringify(res2, null, 3)}`);
                            });
                        });
                        break;
                    case 'ApexClass':
                        conn.tooling.sobject(toolingObj).create({ body: objContent }, (err, res) => {
                            if (err) {
                                return console.error(err);
                            }
                            console.log(`Tooling Crud results: ${JSON.stringify(res, null, 3)}`);
                        });
                        break;
                }
            case 'update':
                conn.tooling.sobject(toolingObj).update({ body: objContent }, (err, res) => {
                    if (err) {
                        return console.error(err);
                    }
                    console.log(`Tooling Crud results: ${JSON.stringify(res, null, 3)}`);
                });
                break;
            /*
                 case 'upsert':
                    conn.tooling.sobject(toolingObj).upsert( {body: objContent},  (err, res) => {
                    if (err) { return console.error(err); }
                    console.log(`Tooling Crud results: ${JSON.stringify(res, null, 3)}`);
                    });
                    break;
                case 'delete':
                    conn.tooling.sobject(toolingObj).delete( {body: objContent},  (err, res) => {
                    if (err) { return console.error(err); }
                    console.log(`Tooling Crud results: ${JSON.stringify(res, null, 3)}`);
                    });
                    break;
            */
            default:
                break;
        }
        // Return an object to be displayed with --json
        return {};
    }
}
Crud.description = messages.getMessage('commandDescription');
Crud.examples = [
    `
    $ sfdx  mohanc:tooling:crud -u TestOrg2 -o ApexClass -m create
  `
];
Crud.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    toolingobj: command_1.flags.string({ char: 'o', description: messages.getMessage('toolingObjectName') }),
    method: command_1.flags.string({ char: 'm', description: messages.getMessage('crudMethod') }),
    objcontentfilename: command_1.flags.string({ char: 'a', description: messages.getMessage('objContentFilename') }),
    aurabundlelabel: command_1.flags.string({ char: 'l', description: messages.getMessage('auraBundleLabel') }),
    auratype: command_1.flags.string({ char: 't', description: messages.getMessage('auraType') })
};
// Comment this out if your command does not require an org username
Crud.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Crud.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Crud.requiresProject = false;
exports.default = Crud;
//# sourceMappingURL=crud.js.map