"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const sfdcLogin_1 = require("../../../helper/sfdcLogin");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'tooling.describe');
class Describe extends command_1.SfdxCommand {
    async run() {
        const loginfilename = this.flags.loginfilename || 'NONE';
        const orgname = this.flags.orgname || 'org40';
        const outputformat = this.flags.outputformat || 'csv';
        let sobjectName = this.flags.sobjectname;
        if (loginfilename !== 'NONE') { // sandbox/prod access
            const forceLogin = new sfdcLogin_1.SfdcLogin(orgname);
            const sfdcConn = await forceLogin.sfdcLogin(loginfilename);
            // console.log(`*** userInfo: ${JSON.stringify(sfdcConn.userInfo, null, 2)}`);
            const result = await sfdcConn.conn.tooling.sobject(sobjectName).describe((err, res) => {
                if (err) {
                    return console.error(err);
                }
                console.log('Label : ' + res.label);
                console.log('Num of Fields : ' + res.fields.length);
                for (const fld of res.fields) {
                    console.log(fld.name);
                }
            });
        }
        else { // Scratch org
            const conn = this.org.getConnection();
            // conn.tooling.sobject(sobjectName).find().execute()
            const result = await conn.tooling.sobject(sobjectName).describe((err, res) => {
                if (err) {
                    return console.error(err);
                }
                console.log('Label : ' + res.label);
                console.log('Num of Fields : ' + res.fields.length);
                for (const fld of res.fields) {
                    console.log(fld.name);
                }
            });
        }
        // Return an object to be displayed with --json
        return {};
    }
}
Describe.description = messages.getMessage('commandDescription');
Describe.examples = [
    ` 
      # Scratch org query
      sfdx mohanc:tooling:describe  -s 

    `
];
Describe.flagsConfig = {
    loginfilename: command_1.flags.string({ char: 'l', description: messages.getMessage('loginfileNameDescription') }),
    orgname: command_1.flags.string({ char: 'o', description: messages.getMessage('orgnameDescription') }),
    sobjectname: command_1.flags.string({ char: 's', description: messages.getMessage('sobjectName') })
};
// Comment this out if your command does not require an org username
Describe.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Describe.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Describe.requiresProject = false;
exports.default = Describe;
//# sourceMappingURL=describe.js.map