"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'tooling.execute');
class Execute extends command_1.SfdxCommand {
    async run() {
        // read the apex code file
        const apexInputFilename = this.flags.apexcodefilename || 'apexInput.cls';
        const apexCode = fs.readFileSync(apexInputFilename, 'utf8');
        console.log(`apexCode: ${apexCode}`);
        // this.org is guaranteed because requiresUsername=true, as opposed to supportsUsername
        // get the connection
        const conn = this.org.getConnection();
        conn.tooling.executeAnonymous(apexCode, (err, res) => {
            if (err) {
                return console.error(err);
            }
            console.log('compiled?: ' + res.compiled); // compiled successfully
            console.log('executed?: ' + res.success); // executed successfully
            console.log(res);
        });
        // Return an object to be displayed with --json
        return { orgId: this.org.getOrgId() };
    }
}
Execute.description = messages.getMessage('commandDescription');
Execute.examples = [
    `

  ** ${messages.getMessage('commandDescription')} **
  
  $ sfdx  mohanc:tooling:execute -u TestOrg2 -a apexCode.cls
  `
];
Execute.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    apexcodefilename: command_1.flags.string({ char: 'a', description: messages.getMessage('apexCodeFilename') }),
};
// Comment this out if your command does not require an org username
Execute.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Execute.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Execute.requiresProject = false;
exports.default = Execute;
//# sourceMappingURL=execute.js.map