"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
const lexUtil_1 = require("../../../../helper/lexUtil");
const path = require("path");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'tooling.crud');
class Create extends command_1.SfdxCommand {
    async run() {
        const toolingObj = 'AuraDefinition';
        const lexUtil = new lexUtil_1.LexUtil();
        // const template = 'helloWorld';
        const auraBundleLabel = this.flags.aurabundlelabel;
        const template = this.flags.template;
        const kind = this.flags.kind;
        const folder = this.flags.folder || 'NONE';
        const auraFolder = 'aura';
        const ps = path.sep;
        let pathToWrite = '';
        // create folder/aura if required
        if (folder !== 'NONE') {
            if (!fs.existsSync(folder)) {
                fs.mkdirSync(`${folder}`);
                fs.mkdirSync(`${folder}${ps}${auraFolder}`);
                fs.mkdirSync(`${folder}${ps}${auraFolder}${ps}${auraBundleLabel}`);
                pathToWrite = `${folder}${ps}${auraFolder}${ps}${auraBundleLabel}`;
            }
        }
        // this.org is guaranteed because requiresUsername=true, as opposed to supportsUsername
        // get the connection
        const conn = this.org.getConnection();
        const orgApiVersion = conn.getApiVersion();
        // console.log(`apiVersion: ${orgApiVersion}`);
        const instanceURL = conn.instanceUrl;
        const lexBundle = 'A Lightning Component Bundle';
        // kind determines item list
        const itemsToCreate = {
            COMPONENT: [
                'COMPONENT',
                // 'APPLICATION',
                'CONTROLLER',
                'HELPER',
                'STYLE',
                // 'EVENT',
                'SVG'
            ],
            APPLICATION: [
                'APPLICATION',
                'CONTROLLER',
                'HELPER',
                'STYLE',
                'SVG',
                'OPEN'
            ],
            EVENT: [
                'EVENT'
            ]
        };
        const rightKind = (kind === 'COMPONENT' || kind === 'APPLICATION' || kind === 'EVENT');
        switch (toolingObj) {
            case 'AuraDefinition':
                // let us create the bundle first
                conn.tooling.sobject(`${toolingObj}Bundle`).create({ description: lexBundle,
                    developerName: auraBundleLabel.replace(/ /g, ''),
                    masterLabel: auraBundleLabel,
                    apiVersion: orgApiVersion }, (err, res) => {
                    if (err) {
                        return console.error(err);
                    }
                    console.log(`Tooling Crud results ${toolingObj}Bundle: ${JSON.stringify(res, null, 3)}`);
                    // get the id of the bundle created
                    const bundleId = res['id'];
                    console.log(`bundleId: ${bundleId}`);
                    for (const item of itemsToCreate[kind]) {
                        if (item === 'OPEN') {
                            // open the browser
                            const url = `${instanceURL}/c/${auraBundleLabel}.app`;
                            console.log(`open ${url}`);
                            // opn (url);
                            return;
                        }
                        const fmt = lexUtil.getFormat(item);
                        const fileFmt = lexUtil.getFileFormat(item);
                        // Component
                        conn.tooling.sobject(toolingObj).create({ defType: item,
                            source: lexUtil.getTemplate(template)[item],
                            format: fmt,
                            AuraDefinitionBundleId: bundleId }, (err2, res2) => {
                            if (err2) {
                                return console.error(err2);
                            }
                            console.log(`Tooling Crud results: ${JSON.stringify(res2, null, 3)}`);
                            if (folder !== 'NONE' && rightKind && pathToWrite !== '') {
                                fs.writeFileSync(`${pathToWrite}${ps}${auraBundleLabel}.${fileFmt}`, lexUtil.getTemplate(template)[item]);
                            }
                        });
                    }
                });
                break;
        }
        // Return an object to be displayed with --json
        return {};
    }
}
Create.description = messages.getMessage('commandDescription');
Create.examples = [
    `
    $ sfdx  mohanc:tooling:lightning:create -l greeter  -k COMPONENT|APPLICATION|EVENT -t helloWorld|farmers
  `
];
Create.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    aurabundlelabel: command_1.flags.string({ char: 'l', description: messages.getMessage('auraBundleLabel') }),
    kind: command_1.flags.string({ char: 'k', description: messages.getMessage('kind') }),
    template: command_1.flags.string({ char: 't', description: messages.getMessage('template') }),
    folder: command_1.flags.string({ char: 'f', description: messages.getMessage('folder') })
};
// Comment this out if your command does not require an org username
Create.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Create.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Create.requiresProject = false;
exports.default = Create;
//# sourceMappingURL=create.js.map