"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs");
const json2csv_1 = require("../../../helper/json2csv");
const sfdcLogin_1 = require("../../../helper/sfdcLogin");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfdx-mohanc-plugins', 'tooling.query');
class Query extends command_1.SfdxCommand {
    async run() {
        // get the connection
        const conn = this.org.getConnection();
        const loginfilename = this.flags.loginfilename || 'NONE';
        const orgname = this.flags.orgname || 'org40';
        const queryFilename = this.flags.queryfilename || 'query.soql';
        const query = fs.readFileSync(queryFilename, 'utf8');
        const outputformat = this.flags.outputformat || 'csv';
        /*
    
        conn.tooling
      .query(" SELECT DeveloperName, Active FROM LookupFilter",
        function(err, result) {
      if (err) { return console.error(err); }
      console.log("total : " + result.totalSize);
      console.log("fetched : " + result.records.length);
      });
      */
        if (loginfilename !== 'NONE') { // sandbox/prod access
            const forceLogin = new sfdcLogin_1.SfdcLogin(orgname);
            const sfdcConn = await forceLogin.sfdcLogin(loginfilename);
            // console.log(`*** userInfo: ${JSON.stringify(sfdcConn.userInfo, null, 2)}`);
            const queryResults = await sfdcConn.conn.tooling.query(query);
            switch (outputformat) {
                case 'csv':
                    const json2csv = new json2csv_1.JSON2CSVParserUtil(queryResults.records, {});
                    console.log(json2csv.parse2csv());
                    break;
                case 'json':
                    console.log(queryResults.records);
                    break;
                default:
                    console.log(queryResults.records);
                    break;
            }
        }
        else { // Scratch org
            const queryResults = await conn.tooling.query(query);
            // console.log(query);
            switch (outputformat) {
                case 'csv':
                    const json2csv = new json2csv_1.JSON2CSVParserUtil(queryResults.records, {});
                    console.log(json2csv.parse2csv());
                    break;
                case 'json':
                    console.log(queryResults.records);
                    break;
                default:
                    console.log(queryResults.records);
                    break;
            }
        }
        // Return an object to be displayed with --json
        return {};
    }
}
Query.description = messages.getMessage('commandDescription');
Query.examples = [
    `

    ** ${messages.getMessage('commandDescription')} **

      Scratch org query
        sfdx mohanc:tooling:query -q LookupFilter.sql  -f csv

    `
];
Query.flagsConfig = {
    queryfilename: command_1.flags.string({ char: 'q', description: messages.getMessage('queryFilename') }),
    loginfilename: command_1.flags.string({ char: 'l', description: messages.getMessage('loginfileNameDescription') }),
    outputformat: command_1.flags.string({ char: 'f', description: messages.getMessage('outputFormatDescription') }),
    orgname: command_1.flags.string({ char: 'o', description: messages.getMessage('orgnameDescription') })
};
// Comment this out if your command does not require an org username
Query.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Query.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Query.requiresProject = false;
exports.default = Query;
//# sourceMappingURL=query.js.map