"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// util class for ERD diagram
class ERDUtil {
    constructor() {
    }
    /*
    ----------------------------------------------------
      getDotty content for the given:
    
      sObjects: list of sObjects for which we need Dot file
      format: vshort | short
              vshort : entities will have only the entity name
              short  : entities bodies will not have the system fields like created date,...
      // dot results.csv.dot -Tsvg -O
    ----------------------------------------------------
    */
    getDotContent(sObjects, format) {
        //console.log(`inside getDotContent with`);
        //console.log(sObjects);
        let selfLinkColor = '#3e7ab7';
        let linkColor = '#ff99cc';
        let lcolor = linkColor;
        let linkFont = 'Monaco';
        let selfLinkFont = 'Arial';
        let lfont = linkFont;
        let linkFontSize = '9';
        let selfLinkFontSize = '12';
        let lfontSize = linkFontSize;
        // header for the dot file
        let header = `
        digraph "Salesforce+ ERD" {  
            graph [  
              rankdir="RL"  
              bgcolor="#efeffd"  
              label="Salesforce ERD "  
              labeljust="r"  
              nodesep="0.18"  
              ranksep="0.46"        
              fontname="Courier"  
              fontsize="9"  
            ];  
            node [  
              fontname="Courier"  
              fontsize="11"  
              shape="plaintext"  
              color="#99ccff"  
            ];  
            edge [ arrowsize="0.8"   ];
        `;
        // here we add dot content
        let dotStr = '';
        let systemFields = ["CreatedDate", "CreatedById", "isDeleted", "LastModifiedDate", "SystemModstamp"];
        const MASTERRECORD = '_';
        for (let sobj of sObjects) {
            // reset the references
            let references = '';
            let entityHeader = `
            ${sobj.name} [shape=none, margin=0, label=<
                <table border="1" cellborder="1" cellspacing="0" bgcolor="#ffeeff" >   
                  <tr><td colspan="3" bgcolor="lightblue"><b>${sobj.name}</b></td></tr>
            `;
            let entityBody = ``;
            // fields
            for (let field of sobj.fields) {
                if (format === 'vshort') {
                    continue;
                }
                if (format === 'short' && systemFields.indexOf(field.name) !== -1) {
                    continue;
                }
                var dataType = field['type'];
                // take care of the references
                if (dataType === 'reference') {
                    for (let ref of field['referenceTo']) {
                        var relationshipName = field['relationshipName'];
                        // not referencing to User sObject and to one of the systemFields?
                        if (!(ref === 'User' && systemFields.indexOf(relationshipName) > -1)) {
                            // recursive reference?
                            if (sobj.name === ref) {
                                lcolor = selfLinkColor;
                                lfont = selfLinkFont;
                                lfontSize = selfLinkFontSize;
                            }
                            else {
                                lcolor = linkColor;
                                lfont = linkFont;
                                lfontSize = linkFontSize;
                            }
                            // living alone, has no referenceTo? 
                            if (relationshipName === null || relationshipName === 'null') {
                                relationshipName = '';
                            }
                            //console.log(relationshipName);
                            // handle referenceTo MasterRecord 
                            if (relationshipName === 'MasterRecord') {
                                relationshipName = MASTERRECORD; // to save space in ERD
                            }
                            references += `
                            "${sobj.name}" : "${field['name']}": w -> 
                                  "${ref}" : "Id" 
                                           : e 
                                          [arrowhead=none 
                                           dir=back 
                                           arrowtail=crowodot 
                                           color="${lcolor}"
                                           label="${relationshipName}"
                                           fontname="${lfont}"
                                           fontsize="${lfontSize}"
                                          ];
                      `;
                            /*
                            references += '"' + sobj.name + '":"' + field['name'] + '":w -> ' +
                                        '"' + ref    + '":"' + 'Id'          + '":e    ' +
                                        '[arrowhead=none dir=back arrowtail=crowodot color="' + lcolor + '" label="' + relationshipName  +
                                          '" fontname="'+ lfont + '" fontsize="' + lfontSize + '" ]; '
                                     ;
                            */
                        }
                    }
                } // reference
                // special rendering for the sObject.Id
                if (field.name === 'Id') {
                    entityBody += ` <tr>
                                        <td  bgcolor="#99ccff" port="${field.name}" align="left">
                                           <b>${field.name}</b>
                                        </td>`;
                }
                else {
                    entityBody += ` <tr>
                                         <td port="${field.name}" align="left">
                                         ${field.name}
                                       </td>`;
                }
                if (field.length !== 0) {
                    entityBody += `<td>${field.type}(${field.length})</td></tr>`;
                }
                else {
                    entityBody += `<td>${field.type}</td></tr>`;
                }
            }
            let entityTail = `            
                </table>
                >
                  URL="#"
                  tooltip=" ${sobj.name} "
                ];
            `;
            dotStr += entityHeader + entityBody + entityTail + references;
        } // sobject
        return header + dotStr + "}";
    }
}
exports.ERDUtil = ERDUtil;
//# sourceMappingURL=ERDUtil.js.map