"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class LexUtil {
    constructor() {
        this.formats = {
            // COMPONENT — component markup
            COMPONENT: 'XML',
            APPLICATION: 'XML',
            // client-side controller
            CONTROLLER: 'JS',
            // EVENT — event definition
            EVENT: 'JS',
            // HELPER — client-side helper
            HELPER: 'JS',
            // INTERFACE — interface definition
            // RENDERER — client-side renderer
            RENDERER: 'JS',
            // STYLE — style (CSS) resource
            STYLE: 'CSS',
            // PROVIDER — reserved for future use
            //  MODEL — deprecated, do not use
            // TESTSUITE — reserved for future use
            // DOCUMENTATION — documentation markup
            DOCUMENTATION: 'XML',
            // TOKENS — tokens collection
            // DESIGN — design definition
            DESIGN: 'XML',
            // SVG — SVG graphic resource
            SVG: 'SVG'
            // ["XML","JS","CSS","TEMPLATE_CSS","SVG"]
        };
        this.fileFormats = {
            // COMPONENT — component markup
            COMPONENT: 'cmp',
            APPLICATION: 'app',
            // client-side controller
            CONTROLLER: 'js',
            // EVENT — event definition
            EVENT: 'evt',
            // HELPER — client-side helper
            HELPER: 'js',
            // INTERFACE — interface definition
            // RENDERER — client-side renderer
            RENDERER: 'js',
            // STYLE — style (CSS) resource
            STYLE: 'css',
            // PROVIDER — reserved for future use
            //  MODEL — deprecated, do not use
            // TESTSUITE — reserved for future use
            // DOCUMENTATION — documentation markup
            DOCUMENTATION: 'auradoc',
            // TOKENS — tokens collection
            // DESIGN — design definition
            DESIGN: 'design',
            // SVG — SVG graphic resource
            SVG: 'svg'
            // ["XML","JS","CSS","TEMPLATE_CSS","SVG"]
        };
        this.templates = {
            helloWorld: {
                COMPONENT: `
<aura:component>
    <p>Hello Lightning!</p>
</aura:component>
        `,
                APPLICATION: `
<aura:application>
    <p>put your components here</p>
</aura:application>
`,
                HELPER: `
({
    helperMethod : function() {
    }
})
        `,
                CONTROLLER: `
({
    myAction : function(component, event, helper) {
    }
})
        `,
                STYLE: `
.THIS {
}
p.THIS {
    font-size:20px;
}
        `,
                SVG: `
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<svg width="120px" height="120px" viewBox="0 0 120 120" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
    <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
        <path d="M120,108 C120,114.6 114.6,120 108,120 L12,120 C5.4,120 0,114.6 0,108 L0,12 C0,5.4 5.4,0 12,0 L108,0 C114.6,0 120,5.4 120,12 L120,108 L120,108 Z" id="Shape" fill="#2A739E"/>
        <path d="M77.7383308,20 L61.1640113,20 L44.7300055,63.2000173 L56.0543288,63.2000173 L40,99.623291 L72.7458388,54.5871812 L60.907727,54.5871812 L77.7383308,20 Z" id="Path-1" fill="#FFFFFF"/>
    </g>
</svg>
        `,
                DESIGN: `
<design:component >
</design:component>
        `,
                RENDERER: `
({
    // Your renderer method overrides go here
})
        `,
                DOCUMENTATION: `
<aura:documentation>
<aura:description>Documentation</aura:description>
    <aura:example name="ExampleName" ref="exampleComponentName" label="Label">
            Example Description
    </aura:example>
</aura:documentation>
        `,
                cmpmeta: `
<AuraDefinitionBundle xmlns="urn:metadata.tooling.soap.sforce.com" fqn="greetComponent">
        <apiVersion>44.0</apiVersion>
    <description>A Lightning Component Bundle</description>
</AuraDefinitionBundle>
        `,
                EVENT: `
<aura:event type="COMPONENT" description="Event template">
<!-- 
Pass context of where the event was fired to the handler. Like this:

<aura:attribute name="context" type="String"/>
For Application Events set the type as "APPLICATION"

At NOTIFIER component:
register this event:

<aura:attribute name="contextValue" type="String"/>
<aura:registerEvent type="c:compEvent" name="componentEventFired"/>
<aura:registerEvent type="c:appEvent"  name="appEventFired"/>

At Client controller side: (firing COMPONENT events)
// Look up event by name, not by type
    var compEvent = cmp.getEvent("componentEventFired");
    compEvent.setParams({ "context" : contextValue });
    compEvent.fire();

At Client controller side: (firing APPLICATION events)
    // Look up event by type with e. prefix
    var appEvent = $A.get("e.c:appEvent");
    appEvent.setParams({ "context" : contextValue });
    appEvent.fire();

At HANDLER component:

<aura:handler event="c:appEvent" action="{!c.handleApplicationEventFired}"/>
<aura:handler name="componentEventFired" event="c:compEvent" action="{!c.handleComponentEventFired}"/>

write the action code in the HANDLER components client-side controller

handleComponentEventFired : function(cmp, event) {
    var context = event.getParam("context");
    // do something with context got from the event fired
 }



-->
</aura:event>
        `
            }
        };
    }
    getTemplate(name) {
        // console.log(JSON.stringify(this.templates, null, 2));
        return this.templates[name];
    }
    getFormat(name) {
        return this.formats[name];
    }
    getFileFormat(name) {
        return this.fileFormats[name];
    }
}
exports.LexUtil = LexUtil;
//# sourceMappingURL=lexUtil.js.map